Index: src/mips/code-stubs-mips.h |
diff --git a/src/mips/code-stubs-mips.h b/src/mips/code-stubs-mips.h |
index 125de1cd8f073e32f6e608f555d473acbe33b542..6f075bc33babf04566cfd8a6aebaf09b7cd04b33 100644 |
--- a/src/mips/code-stubs-mips.h |
+++ b/src/mips/code-stubs-mips.h |
@@ -25,32 +25,23 @@ class StringHelper : public AllStatic { |
Register scratch, |
String::Encoding encoding); |
- // Compare two flat ASCII strings and returns result in v0. |
- static void GenerateCompareFlatAsciiStrings(MacroAssembler* masm, |
- Register left, |
- Register right, |
+ // Compares two flat one-byte strings and returns result in v0. |
+ static void GenerateCompareFlatOneByteStrings( |
+ MacroAssembler* masm, Register left, Register right, Register scratch1, |
+ Register scratch2, Register scratch3, Register scratch4); |
+ |
+ // Compares two flat one-byte strings for equality and returns result in v0. |
+ static void GenerateFlatOneByteStringEquals(MacroAssembler* masm, |
+ Register left, Register right, |
Register scratch1, |
Register scratch2, |
- Register scratch3, |
- Register scratch4); |
- |
- // Compares two flat ASCII strings for equality and returns result in v0. |
- static void GenerateFlatAsciiStringEquals(MacroAssembler* masm, |
- Register left, |
- Register right, |
- Register scratch1, |
- Register scratch2, |
- Register scratch3); |
+ Register scratch3); |
private: |
- static void GenerateAsciiCharsCompareLoop(MacroAssembler* masm, |
- Register left, |
- Register right, |
- Register length, |
- Register scratch1, |
- Register scratch2, |
- Register scratch3, |
- Label* chars_not_equal); |
+ static void GenerateOneByteCharsCompareLoop( |
+ MacroAssembler* masm, Register left, Register right, Register length, |
+ Register scratch1, Register scratch2, Register scratch3, |
+ Label* chars_not_equal); |
DISALLOW_IMPLICIT_CONSTRUCTORS(StringHelper); |
}; |